@@ -23,10 +23,12 @@ import net.sf.launch4j.BuilderException;
 import net.sf.launch4j.config.Config;
 import net.sf.launch4j.config.ConfigPersister;
 
+import org.apache.maven.artifact.versioning.OverConstrainedVersionException;
 import org.apache.maven.plugin.*;
 import org.apache.maven.plugin.logging.*;
 import org.apache.maven.plugin.descriptor.PluginDescriptor;
 import org.apache.maven.project.MavenProject;
+import org.apache.maven.project.MavenProjectHelper;
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.factory.ArtifactFactory;
 import org.apache.maven.artifact.resolver.ArtifactResolver;
@@ -35,6 +37,7 @@ import org.apache.maven.artifact.resolver.ArtifactResolutionException;
 import org.apache.maven.artifact.repository.ArtifactRepository;
 import org.apache.maven.model.Plugin;
 
+
 import org.codehaus.plexus.archiver.UnArchiver;
 import org.codehaus.plexus.archiver.ArchiverException;
 import org.codehaus.plexus.archiver.manager.ArchiverManager;
@@ -55,11 +58,12 @@ public class Launch4jMojo extends AbstractMojo {
 	/**
 	 * The dependencies required by the project.
 	 *
+     * ---old:  parameter default-value="${project.artifacts}"
 	 * @parameter default-value="${project.artifacts}"
 	 * @required
 	 * @readonly
 	 */
-	private Set dependencies;
+	private Collection<Artifact> dependencies;
 	
 	/**
 	 * The user's current project.
@@ -264,10 +268,17 @@ public class Launch4jMojo extends AbstractMojo {
 	 * @parameter
 	 */
 	private VersionInfo versionInfo;
+    
+    /**
+     * Internal project helper component.
+     * @component
+     */
+    private MavenProjectHelper projectHelper;
+
 
 	private File getJar() {
 		File f = new File(jar);
-		if (f.isAbsolute()) return f;
+		if (dontWrapJar || f.isAbsolute()) return f;
 		else return new File(getBaseDir(), jar);
 	}
 
@@ -290,8 +301,10 @@ public class Launch4jMojo extends AbstractMojo {
 		c.setLibs(libs);
 		c.setVariables(vars);
 
-		if (classPath != null) {
-			c.setClassPath(classPath.toL4j(dependencies));
+        if (classPath != null) {
+            final HashSet<Artifact> deps = new HashSet<Artifact>(dependencies);
+//            deps.addAll(project.getDependencyArtifacts());
+            c.setClassPath(classPath.toL4j(getLog(), deps));
 		}
 		if (jre != null) {
 			c.setJre(jre.toL4j());
@@ -311,6 +324,7 @@ public class Launch4jMojo extends AbstractMojo {
 
 		try {
 			b.build();
+            projectHelper.attachArtifact( project, "exe", outfile );
 		} catch (BuilderException e) {
 			getLog().error(e);
 			throw new MojoExecutionException("Failed to build the executable; please verify your configuration.", e);
@@ -427,8 +441,11 @@ public class Launch4jMojo extends AbstractMojo {
 	 */
 	private Artifact chooseBinaryBits() throws MojoExecutionException {
 		String plat;
-		String os = System.getProperty("os.name");
-		getLog().debug("OS = " + os);
+		final String os = System.getProperty("os.name");
+        final String arch = System.getProperty("os.arch");
+
+		getLog().debug("os.name = " + os);
+		getLog().debug("os.arch = " + arch);
 
 		// See here for possible values of os.name:
 		// http://lopica.sourceforge.net/os.html
@@ -437,7 +454,11 @@ public class Launch4jMojo extends AbstractMojo {
 		} else if ("Linux".equals(os)) {
 			plat = "linux";
 		} else if ("Solaris".equals(os) || "SunOS".equals(os)) {
-			plat = "solaris";
+            if ("sparc".equals(arch)) {
+                plat = "solaris";
+            } else {
+                plat = "solaris-x86";
+            }
 		} else if ("Mac OS X".equals(os)) {
 			plat = "mac";
 		} else {
